# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('spotinst')


class _ExportableConfig(types.ModuleType):
    @property
    def account(self) -> Optional[str]:
        """
        Spotinst Account ID
        """
        return __config__.get('account')

    @property
    def enabled(self) -> Optional[bool]:
        """
        Enable or disable the Spotinst provider
        """
        return __config__.get_bool('enabled')

    @property
    def feature_flags(self) -> Optional[str]:
        """
        Spotinst SDK Feature Flags
        """
        return __config__.get('featureFlags')

    @property
    def token(self) -> Optional[str]:
        """
        Spotinst Personal API Access Token
        """
        return __config__.get('token')

